Documentation
¶
Index ¶
Constants ¶
const AdminUserId = 1
Variables ¶
Functions ¶
func InstallPlugin ¶
func InstallPlugin(pluginName, version string, c CommandLine) error
InstallPlugin downloads the plugin code as a zip file from the Grafana.com API and then extracts the zip into the plugins directory.
Types ¶
type CommandLine ¶
type CommandLine interface {
ShowHelp()
ShowVersion()
Application() *cli.App
Args() cli.Args
Bool(name string) bool
Int(name string) int
String(name string) string
StringSlice(name string) []string
GlobalString(name string) string
FlagNames() (names []string)
Generic(name string) interface{}
PluginDirectory() string
RepoDirectory() string
PluginURL() string
}
Source Files
¶
- command_line.go
- commands.go
- install_command.go
- listremote_command.go
- listversions_command.go
- ls_command.go
- remove_command.go
- reset_password_command.go
- upgrade_all_command.go
- upgrade_command.go
Click to show internal directories.
Click to hide internal directories.