Discover Packages
cool-lake.m-2023.workers.dev/grafana/grafana
pkg
services
provisioning
notifiers
package
Version:
v6.1.6+incompatible
Opens a new window with list of versions in this module.
Published: Apr 29, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
var (
ErrInvalidConfigTooManyDefault = errors .New ("Alert notification provisioning config is invalid. Only one alert notification can be marked as default")
)
type NotificationProvisioner struct {
}
Source Files
¶
alert_notifications.go config_reader.go types.go
Click to show internal directories.
Click to hide internal directories.